# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2024-11-07

### Added
- Initial release
- Semantic search functionality using Azure OpenAI embeddings
- Persistent storage support
- Comprehensive error handling
- Logging system

## [0.1.1] - 2024-11-08

### Added
- Bug fixes

## [0.1.2] - 2024-11-10

### Added
- Refactoring to organise into core and functional modules